@@ -1,8 +1,8 @@
 /****************************************************************************
 
- Copyright (C) 2002-2013 Gilles Debunne. All rights reserved.
+ Copyright (C) 2002-2014 Gilles Debunne. All rights reserved.
 
- This file is part of the QGLViewer library version 2.5.2.
+ This file is part of the QGLViewer library version 2.8.0.
 
  http://www.libqglviewer.com - contact@libqglviewer.com
 
@@ -25,12 +25,11 @@
 #include <lib3ds/file.h>
 #include <lib3ds/node.h>
 
-class Viewer : public QGLViewer
-{
-public :
-  Viewer() : file(NULL), current_frame(0.0), camera_name(NULL) {};
+class Viewer : public QGLViewer {
+public:
+  Viewer() : file(NULL), current_frame(0.0), camera_name(NULL){};
 
-protected :
+protected:
   virtual void draw();
   virtual void animate();
   virtual void init();
@@ -41,8 +40,8 @@ protected :
   void loadFile();
   void initScene();
 
-private :
+private:
   Lib3dsFile *file;
   float current_frame;
-  char* camera_name;
+  char *camera_name;
 };
