@@ -1,8 +1,8 @@
 /****************************************************************************
 
- Copyright (C) 2002-2013 Gilles Debunne. All rights reserved.
+ Copyright (C) 2002-2014 Gilles Debunne. All rights reserved.
 
- This file is part of the QGLViewer library version 2.5.2.
+ This file is part of the QGLViewer library version 2.8.0.
 
  http://www.libqglviewer.com - contact@libqglviewer.com
 
@@ -20,19 +20,20 @@
 
 *****************************************************************************/
 
+#include "../Viewer/board.h"
 #include <fstream>
 #include <stdio.h>
-#include "../Viewer/board.h"
 
-int main (int argc, char ** argv)
-{    
+int main(int argc, char **argv) {
   Board board;
-  
+
   if (argc != 3) {
-	  std::cout << "This AI blobwar player requires 2 parameters. It should be called by the main blobWar viewer application." << std::endl;
-	  exit(1);
+    std::cout << "This AI blobwar player requires 2 parameters. It should be "
+                 "called by the main blobWar viewer application."
+              << std::endl;
+    exit(1);
   }
-  
+
   std::ifstream file(argv[1]);
   file >> board;
   file.close();
