@@ -1,8 +1,8 @@
 /****************************************************************************
 
- Copyright (C) 2002-2013 Gilles Debunne. All rights reserved.
+ Copyright (C) 2002-2014 Gilles Debunne. All rights reserved.
 
- This file is part of the QGLViewer library version 2.5.2.
+ This file is part of the QGLViewer library version 2.8.0.
 
  http://www.libqglviewer.com - contact@libqglviewer.com
 
@@ -20,14 +20,12 @@
 
 *****************************************************************************/
 
-#include <qgl.h>
 #include "object.h"
 
 using namespace qglviewer;
 
-void Object::draw() const
-{
-  static GLUquadric* quad = gluNewQuadric();
+void Object::draw() const {
+  static GLUquadric *quad = gluNewQuadric();
 
   glPushMatrix();
   glMultMatrixd(frame.matrix());
